@@ -169,7 +169,8 @@ def fgsm_distribution_factory(epsilon: List[float],
                               iteration_step: int = 10,
                               ascend: bool = True,
                               mask: List[int] = [],
-                              step_length: List[int] = []
+                              step_length: List[int] = [],
+                              target_output: int = 0,
                               ) -> FGSMDistribution:
     """
     Create a distribution object containing all the parameters needed to
@@ -194,7 +195,9 @@ def fgsm_distribution_factory(epsilon: List[float],
 
     If the task of the attacked model is regression, the perturbation tries to
     increase or decrease - depending on the value of ascend - the value of the
-    output node (the loss). If the task is classification the perturbation
+    output node (the loss). For multiregression models, it tries to increase
+    or decrease the value of the output node whose index is given by
+    target_output. If the task is classification, the perturbation
     tries to decrease the probability value of the original prediction.
 
     Currently, this attack strategy can be applied to:
@@ -213,7 +216,9 @@ def fgsm_distribution_factory(epsilon: List[float],
         perturbed by the attack, the list length must be the number of
         variables
     :param step_length: number of time steps with constant value before next
-        increase or decrease
+    increase or decrease
+    :param target_output: the index of the output neuron the algorithm tries
+                          to modify (only relevant for multiregression models)
     """
     distribution = FGSMDistribution(
         epsilon=epsilon,
@@ -223,6 +228,7 @@ def fgsm_distribution_factory(epsilon: List[float],
         ascend=ascend,
         mask=mask,
         step_length=step_length,
+        target_output=target_output,
         saver=1
     )
     return distribution
@@ -233,7 +239,8 @@ def correlation_distribution_factory(epsilon: List[float],
                                      perturbation_length: int = 100000,
                                      iteration_step: int = 10,
                                      mask: List[int] = [],
-                                     step_length: List[int] = []
+                                     step_length: List[int] = [],
+                                     target_output: int = 0,
                                      ) -> CorrelationDistribution:
     """
     Create a distribution object containing all the parameters needed to
@@ -249,11 +256,12 @@ def correlation_distribution_factory(epsilon: List[float],
     should be the same or if start_index/perturbation_length limits the number
     of data points that can be perturbed in a data file.
 
-    The perturbations are generated via a gradient-based optimization algorithm
-    whose objective function penalizes the correlation between the predicted
-    values and the true labels.
+    The perturbations are generated via a gradient-based optimization
+    algorithm whose objective function penalizes the correlation between the
+    predicted values and the true labels. For multiregression models, the
+    objective function considers the output coordinate given by target_output.
 
-    Currently, this attack strategy can be applied to Keras regression
+    Currently, this attack strategy can be applied to Keras (multi-)regression
     recurrent ML models and the data set must consist only of quantitative
     variables.
 
@@ -274,6 +282,7 @@ def correlation_distribution_factory(epsilon: List[float],
         iteration_step=iteration_step,
         mask=mask,
         step_length=step_length,
+        target_output=target_output,
         saver=1
     )
     return distribution
@@ -284,7 +293,8 @@ def peak_distribution_factory(epsilon: List[float],
                               perturbation_length: int = 100000,
                               iteration_step: int = 10,
                               mask: List[int] = [],
-                              step_length: List[int] = []
+                              step_length: List[int] = [],
+                              target_output: int = 0,
                               ) -> PeakDistribution:
     """
     Create a distribution object containing all the parameters needed to
@@ -299,12 +309,14 @@ def peak_distribution_factory(epsilon: List[float],
     after start_index. The attack compares the MSE values of the different
     perturbations and using gradient information it optimizes the deviation of
     the predictions from the labels to find the consecutive data points in the
-    data set where the highest possible "peak" error is achieved.
+    data set where the highest possible "peak" error is achieved. For
+    multiregression models, only the error of the output variable whose index
+    is given by target_output is considered.
 
     The idea is to find the area in the file after start_index where the
     perturbation of perturbation_length values has the biggest impact.
 
-    Currently, this attack strategy can be applied to Keras regression
+    Currently, this attack strategy can be applied to Keras (multi-)regression
     recurrent ML models and the data set must consist only of quantitative
     variables.
 
@@ -316,7 +328,10 @@ def peak_distribution_factory(epsilon: List[float],
         perturbed by the attack, the list length must be the number of
         variables
     :param step_length: number of time steps with constant value before next
-        increase or decrease
+    increase or decrease
+    :param target_output: the index of the output neuron the algorithm tries
+                          to maximize the error of (only relevant for
+                          multiregression models)
     """
     distribution = PeakDistribution(
         epsilon=epsilon,
@@ -325,6 +340,7 @@ def peak_distribution_factory(epsilon: List[float],
         iteration_step=iteration_step,
         mask=mask,
         step_length=step_length,
+        target_output=target_output,
         saver=1
     )
     return distribution
@@ -338,7 +354,8 @@ def blackbox_distribution_factory(epsilon: List[float],
                                   evolutionary_step: int = 5,
                                   ascend: bool = True,
                                   mask: List[int] = [],
-                                  step_length: List[int] = []
+                                  step_length: List[int] = [],
+                                  target_output: int = 0,
                                   ) -> BlackboxDistribution:
     """
     Create a distribution object containing all the parameters needed to
@@ -359,9 +376,10 @@ def blackbox_distribution_factory(epsilon: List[float],
     the fitness function is determined by the output neuron of the given
     regression model. Population candidates are generated via a uniform
     distribution, and the crossover is given by an addition and clipping
-    operation.
+    operation. If the given model is a multiregression model, the algorithm
+    aims to change the output neuron with the index given by target_output.
 
-    Currently, this attack strategy can be applied to Keras regression
+    Currently, this attack strategy can be applied to Keras (multi-)regression
     recurrent ML models and the data set must consist only of quantitative
     variables.
 
@@ -378,7 +396,9 @@ def blackbox_distribution_factory(epsilon: List[float],
         perturbed by the attack, the list length must be the number of
         variables
     :param step_length: number of time steps with constant value before next
-        increase or decrease
+    increase or decrease
+    :param target_output: the index of the output neuron the algorithm tries
+                          to modify (only relevant for multiregression models)
     """
     distribution = BlackboxDistribution(
         epsilon=epsilon,
@@ -390,6 +410,7 @@ def blackbox_distribution_factory(epsilon: List[float],
         ascend=ascend,
         mask=mask,
         step_length=step_length,
+        target_output=target_output,
         saver=1
     )
     return distribution
