@@ -17,6 +17,7 @@ def blackbox(data: str,
              ascend: bool = True,
              mask: List[int] = [],
              step_length: List[int] = [],
+             target_output: int = 0,
              title="Config Black-Box Attack"
              ) -> RequestModel:
     """
@@ -35,9 +36,10 @@ def blackbox(data: str,
     the fitness function is determined by the output neuron of the given
     regression model. Population candidates are generated via a uniform
     distribution, and the crossover is given by an addition and clipping
-    operation.
+    operation. If the given model is a multiregression model, the algorithm
+    aims to change the output neuron with the index given by target_output.
 
-    Currently, this attack strategy can be applied to Keras regression
+    Currently, this attack strategy can be applied to Keras (multi-)regression
     recurrent ML models and the data set must consist only of quantitative
     variables.
 
@@ -57,6 +59,8 @@ def blackbox(data: str,
         variables
     :param step_length: number of time steps with constant value before next
         increase or decrease
+    :param target_output: the index of the output neuron the algorithm tries
+                          to modify (only revelant for multiregression models)
     :param title: title of the configuration (default: "Config Black-Box
         Attack")
     :return: a RequestModel instance containing all the information needed to
@@ -77,7 +81,8 @@ def blackbox(data: str,
             "ascend": ascend,
             "mask": mask,
             "step_length": step_length,
-            "saver": 1
+            "saver": 1,
+            "target_output": target_output,
         }}
     )
     return RequestModel(toml_dict)
