@@ -5,11 +5,14 @@ from aidkitcli.core.request_model import RequestModel
 from aidkitcli.data_access.stored_model_access import load_stored_model
 
 
-def data_investigation(data: str, model: str,
-                       title="Config Data Investigation Analysis") -> RequestModel:
+def data_investigation(
+    data: str, model: str, target_output: int = 0, title="Config Data Investigation Analysis"
+) -> RequestModel:
     """
     Create a Request model to analyze the statistics and distribution of the
-    provided data through five plots and the value of four metrics.
+    provided data through five plots and the value of four metrics. If the
+    model has multiple outputs, only the output whose index is given by
+    target_output is considered.
 
     The plots displayed after executing this request are:
         - "File Length Plot" - comparison between the different lengths of the
@@ -33,13 +36,16 @@ def data_investigation(data: str, model: str,
         - maximum value of length of the provided data files
 
     This analysis supports the following models:
-        - Keras regression recursive models
+        - Keras (multi-)regression recursive models
         - Keras classification feedforward models
         - scikit-learn classification feedforward models
     The data set must have more than 4 quantitative variables.
 
     :param data: name of the data set
     :param model: path to the TOML file that contains the model information
+    :param target_output: the index of the output column used for the
+                          statistical calculations (only relevant for
+                          multivariable regression)
     :param title: title of the configuration (default: "Config Data
         Investigation Analysis")
     :return: a RequestModel instance containing all the information needed to
@@ -50,6 +56,6 @@ def data_investigation(data: str, model: str,
         title=title,
         data=data,
         stored_model=stored_model,
-        data_investigation={}
+        data_investigation={"target_output": target_output},
     )
     return RequestModel(toml_dict)
